
#ifndef _QUOTA_H_
#define _QUOTA_H_

#include <linux/types.h>

/*
 * Command definitions for the 'quotactl' system call.
 * The commands are broken into a main command defined below
 * and a subcommand that is used to convey the type of
 * quota that is being manipulated (see above).
 */
#define SUBCMDMASK  0x00ff
#define SUBCMDSHIFT 8
#define QCMD(cmd, type)  (((cmd) << SUBCMDSHIFT) | ((type) & SUBCMDMASK))

#define Q_SYNC      0x800001	/* sync disk copy of a filesystems quotas */
#define Q_QUOTAON   0x800002	/* turn quotas on */
#define Q_QUOTAOFF  0x800003	/* turn quotas off */
#define Q_GETFMT    0x800004	/* get quota format used on given filesystem */
#define Q_GETINFO   0x800005	/* get information about quota files */
#define Q_SETINFO   0x800006	/* set information about quota files */
#define Q_GETQUOTA  0x800007	/* get user quota structure */
#define Q_SETQUOTA  0x800008	/* set user quota structure */

#define Q_ADD_DQHASH  0x2100    /* add dqhash */
#define Q_REM_DQHASH  0x2200    /* remove dqhash */
#define Q_GET_DLIMIT  0x2300    /* get disk limit */
#define Q_SET_DLIMIT  0x2400    /* set disk limit */

long quotactl __P ((unsigned int, const char *, int, caddr_t));

struct dli_limits {
        __u32 dli_inodes_used;	    	/* used inodes */
        __u32 dli_inodes_total;     	/* total inodes */

        __u32 dli_blocks_used;	    	/* used blocks */
        __u32 dli_blocks_total;     	/* total blocks */

        __u32 dli_reserved; 	    	/* percentage reserved for root */
};

#endif /* _QUOTA_H_ */
